package com.sd.business.service.order.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.sd.business.entity.order.dto.OrderSkuDto;
import com.sd.business.entity.order.dto.OrderSkuSelectDto;
import com.sd.business.entity.order.po.OrderSku;
import com.sd.business.entity.order.vo.OrderSkuVo;
import com.sd.business.mapper.order.OrderSkuMapper;
import com.sd.business.service.order.OrderSkuService;
import com.sd.framework.util.Assert;
import com.sd.framework.util.sql.Sql;
import org.springframework.stereotype.Service;


/**
 * <p>
 * 订单sku 服务实现类
 * </p>
 *
 * @author
 * @since 2023-12-11
 */
@Service
public class OrderSkuServiceImpl extends ServiceImpl<OrderSkuMapper, OrderSku> implements OrderSkuService {

    @Override
    public Page<OrderSkuVo> getPage(OrderSkuSelectDto dto) {

        Page<OrderSkuVo> page = Sql.create(OrderSkuVo.class)
                .selectAll(OrderSku.class)
                .from(OrderSku.class)
                .orderByDesc(OrderSku::getId)
                .page(dto);

        return page;
    }

    @Override
    public OrderSkuVo detail(Long id) {

        OrderSkuVo vo = Sql.create(OrderSkuVo.class)
                .selectAll(OrderSku.class)
                .from(OrderSku.class)
                .eq(OrderSku::getId, id)
                .one();

        Assert.notNull(vo, "未知数据");

        return vo;
    }

    @Override
    public void add(OrderSkuDto dto) {
        save(dto);
    }

    @Override
    public void edit(OrderSkuDto dto) {
        updateById(dto);
    }

    @Override
    public void delete(Long id) {
        removeById(id);
    }

}
